@@ -1,3 +1 @@
-import json
-import pandas as pd
 from company_name_matching.matching_function import DefaultMatching
\ No newline at end of file
